<?php

namespace App\Forms;


use App\Entity\Pracoviste;
use App\Entity\Pracovnik;
use App\Entity\Proces;
use App\Entity\Produkt;
use Kdyby\Doctrine\EntityManager;

class ProcesForm
{

	/** @var  FormFactory */
	protected $formFactory;

	/** @var  EntityManager */
	protected $em;

	public function __construct(FormFactory $formFactory, EntityManager $em)
	{
		$this->formFactory = $formFactory;
		$this->em = $em;
	}

	public function create(callable $onSuccess) {
		$form = $this->formFactory->create();

		$form->addText('nazev', 'Název')
			->setRequired();

		$form->addTextArea('popis', 'Popis')
			->setRequired();

		$form->addText('dobaTrvaniVMin', 'Doba trvání (min.)')
			->setRequired()
			->setType('number');

		$form->addText('kapacitaPrirazenychPracovniku', 'Kapacita přiřazených pracovníků')
			->setRequired()
			->setType('number');

		$form->addText('cenaProcesu', 'Cena')
			->setDisabled()
			->setDefaultValue("0 Kč");

		$form->addMultiSelect('prirazeniPracovnici', 'Přiřazení pracovníci', $this->getPracovnici())
			->setAttribute('class', 'chosen')
			->setAttribute('data-placeholder', "Vyberte pracovníky");

		$form->addSelect('prirazeneProdukty', 'Přiřazené produkty', $this->getProdukty())
				->setPrompt('---')
				->setAttribute('class', 'chosen');

		$form->addMultiSelect('pridelenePracoviste', 'Přidělné pracoviště', $this->getPracoviste())
			->setAttribute('data-placeholder', "Vyberte pracoviště")
			->setAttribute('class', 'chosen');

		$form->addHidden('id');

		$form->addSubmit('send', 'Uložit');

		$form->onSuccess[] = function($form, $values) use($onSuccess) {
			if($values->id) {
				/** @var Proces $entity */
				$entity = $this->em->getRepository(Proces::class)->find($values->id);
				$entity->clearPridelenaPracoviste();
				$entity->clearPrirazeniPracovnici();
			}else{
				$entity = new Proces();
			}
			$doba = $values->dobaTrvaniVMin;
			$cenaProcesu = 0;

			$entity->setNazev($values->nazev);
			$entity->setPopis($values->popis);
			$entity->setDobaTrvaniVMin($doba);
			$entity->setKapacitaPrirazenychPracovniku($values->kapacitaPrirazenychPracovniku);
			$entity->setCenaProcesu(0);



			if($values->prirazeneProdukty) {
				$produkt = $this->em->getRepository(Produkt::class)->find($values->prirazeneProdukty);
				$cenaProcesu += $produkt->getCena();
				$entity->setPrirazeneProdukty($produkt);
			}

			$this->em->persist($entity);
			$this->em->flush();

			if(count($values->prirazeniPracovnici)) {
				$repo = $this->em->getRepository(Pracovnik::class);
				foreach($values->prirazeniPracovnici as $p) {
					/** @var Pracovnik $pracovnik */
					$pracovnik = $repo->find($p);

					$cenaProcesu += $doba * ($pracovnik->getPracovniPozice()->getHodinovaMzda()/60);

					$pracovnik->addPridruzenyProces($entity);
					$this->em->persist($pracovnik);
				}
				$this->em->flush();
			}

			if(count($values->pridelenePracoviste)) {
				$repo = $this->em->getRepository(Pracoviste::class);
				foreach($values->pridelenePracoviste as $pp) {
					/** @var Pracoviste $pracoviste */
					$pracoviste = $repo->find($pp);
					$pracoviste->addPrirazeneProcesy($entity);
					$this->em->persist($pracoviste);
				}
				$this->em->flush();
			}

			$entity->setCenaProcesu($cenaProcesu);
			$this->em->persist($entity);
			$this->em->flush();

			$onSuccess();
		};

		return $form;
	}

	private function getPracovnici() {
		$en = $this->em->getRepository(Pracovnik::class)->findAll();

		$pr = [];
		/** @var Pracovnik $p */
		foreach($en as $p) {
			$pr[$p->getId()] = $p->getPrijmeni()." ".$p->getJmeno();
		}

		return $pr;
	}

	private function getProdukty() {
		$en = $this->em->getRepository(Produkt::class)->findAll();

		$pr = [];
		/** @var Produkt $p */
		foreach($en as $p) {
			if(!$p->getPrirazenoProcesum()) {
				$pr[$p->getId()] = $p->getNazev();
			}
		}

		return $pr;
	}

	private function getPracoviste() {
		$en = $this->em->getRepository(Pracoviste::class)->findAll();

		$pr = [];
		/** @var Pracviste $p */
		foreach($en as $p) {
				$pr[$p->getId()] = $p->getNazev();
		}

		return $pr;
	}



}