<?php

namespace App\Forms;


use App\Entity\Pracoviste;
use App\Entity\Produkt;
use Doctrine\ORM\EntityManager;

class ProduktForm
{
	/** @var FormFactory  */
	protected $formFactory;

	/** @var  EntityManager */
	protected $em;

	public function __construct(FormFactory $formFactory, EntityManager $em)
	{
		$this->formFactory = $formFactory;
		$this->em = $em;
	}

	public function create(callable $onSuccess) {
		$form = $this->formFactory->create();

		$form->addText('nazev','Název')
			->setRequired();

		$form->addTextArea('popis', 'Popis');

		$form->addText('cena', 'Cena')
			->setRequired()
			->setType('number');

		$form->addSelect('umisteni', 'Umístění', $this->getPracoviste())
			->setAttribute('class', 'chosen');

		$form->addHidden('id');

		$form->addSubmit('send', 'Uložit');

		$form->onSuccess[] = function($form, $values) use($onSuccess) {
			if($values->id) {
				$entity = $this->em->getRepository(Produkt::class)->find($values->id);
			}else{
				$entity = new Produkt();
			}

			$entity->setNazev($values->nazev);
			$entity->setPopis($values->popis);
			$entity->setCena($values->cena);

			if($values->umisteni) {
				$pracoviste = $this->em->getRepository(Pracoviste::class)->find($values->umisteni);
				$entity->setUmisteni($pracoviste);
			}

			$this->em->persist($entity);
			$this->em->flush();

			$onSuccess();
		};


		return $form;
	}

	private function getPracoviste() {
		$en = $this->em->getRepository(Pracoviste::class)->findAll();

		$pr = [];
		/** @var Pracoviste $p */
		foreach($en as $p) {
			$pr[$p->getId()] = $p->getNazev();
		}

		return $pr;
	}

}