<?php

namespace App\Model;

use App\Entity\User;
use Doctrine\DBAL\DBALException;
use Doctrine\ORM\EntityManager;
use Nette;
use Nette\Security\Passwords;


/**
 * Users management.
 */
class UserManager implements Nette\Security\IAuthenticator
{
	use Nette\SmartObject;

	const
		TABLE_NAME = 'users',
		COLUMN_ID = 'id',
		COLUMN_NAME = 'name',
		COLUMN_PASSWORD_HASH = 'password',
		COLUMN_EMAIL = 'email',
		COLUMN_ROLE = 'role';

	/** @var  EntityManager */
	private $em;

	public function __construct(EntityManager $em)
	{
		$this->em = $em;
	}


	/**
	 * Performs an authentication.
	 * @return Nette\Security\Identity
	 * @throws Nette\Security\AuthenticationException
	 */
	public function authenticate(array $credentials)
	{
		list($username, $password) = $credentials;

		$row = $this->em->getRepository(User::class)->findOneBy(['username'=>$username]);

		if (!$row) {
			throw new Nette\Security\AuthenticationException('The username is incorrect.', self::IDENTITY_NOT_FOUND);

		} elseif (!Passwords::verify($password, $row->getPassword())) {
			throw new Nette\Security\AuthenticationException('The password is incorrect.', self::INVALID_CREDENTIAL);

		}

		//$arr = $row->toArray();
		//unset($arr[self::COLUMN_PASSWORD_HASH]);
		return new Nette\Security\Identity($row->getId(), NULL, ['username'=>$row->getUsername(), 'name'=>$row->getName(), 'email'=>$row->getEmail()]);
	}


	/**
	 * Adds new user.
	 * @param  string
	 * @param  string
	 * @param  string
	 * @return void
	 * @throws DuplicateNameException
	 */
	public function add($username, $name, $email, $password)
	{
		try {
			$user = new User();
			$user->setEmail($email);
			$user->setPassword(Passwords::hash($password));
			$user->setName($name);
			$user->setUsername($username);

			$this->em->persist($user);
			$this->em->flush();

		} catch (DBALException $e) {
			throw new DuplicateNameException;
		}
	}

	public function edit($id, $name, $email, $password = NULL) {
		/** @var User $user */
		$user = $this->em->getRepository(User::class)->find($id);

		if(!$user) return FALSE;

		$user->setName($name);
		$user->setEmail($email);

		if($password) {
			$user->setPassword(Passwords::hash($password));
		}

		$this->em->persist($user);
		$this->em->flush();
	}

}



class DuplicateNameException extends \Exception
{}
